@@ -50,6 +50,8 @@ class Chemical(Entity):
             properties.Density = density
         if (molecular_weight):
             properties.MolecularWeight = molecular_weight
+        if (equivalents):
+            equivalents = str(equivalents)
 
         params = {
             "equivalence": equivalents,
