@@ -116,6 +116,6 @@ def exportExperiment(experiment, root_path):
 
     # get pdf
     if includePDF:
-        pdf = htmlToPDF(experiment.__user__, html_with_paths)
+        pdf = htmlToPDF(experiment.__user__, html)
         with open(expDir.joinpath(f'{expDir.name}.pdf'), 'wb') as out:
             out.write(pdf)
