@@ -11,7 +11,9 @@ from labstep.constants import UNSPECIFIED
 
 
 def getDataFields(entity, count=1000, extraParams={}):
-
+    if hasattr(entity, 'metadata_thread') is False:
+        entity.update()
+        
     if isinstance(entity, ProtocolVersion):
         params = {
             "metadata_thread_id": entity.metadata_thread["id"]}
