@@ -155,8 +155,7 @@ class ProtocolVersion(EntityWithComments):
             protocol = user.getProtocol(17000)
             metadata = protocol.getDataFields()
         """
-        if hasattr(self, 'metadata_thread') is False:
-            self.update()
+        self.update()
 
         if "metadatas" not in self.metadata_thread:
             return []
